@@ -8,6 +8,6 @@ Ideally these would be sourced from existing libraries,
 but:
 
 - are frequently not available yet (lz4, zstd),
-- are available but in poor form (crc32), or
+- are available but in poor form (CRC32), or
 - don't really make sense as a library (xxHash).
 """
